/**
 * Save SASS WeBuilder plugin
 * ---------------------------------------------------------------------------
 * By: Anderson Salas (anderson@ingeniasoftware.com.ve)
 * Version: 0.1
 * August 2016
 * ---------------------------------------------------------------------------
 */

// Global options
var options_sass_path, options_compass_path, options_output_type, options_source_map, options_output_target, options_sass_auto_compiple, options_compass_auto_compile = "";

var input_compass_inst_path, image_bootstrap_theme, image , combo_bootstrap_theme, cform,cbutton_ok, cbutton_cancel;

var Manual = false;
var ManualType = "";

function LoadSettings()
{
    options_sass_path            = Script.ReadSetting("sass_path","");
    options_compass_path         = Script.ReadSetting("compass_path","");
    options_output_type          = Script.ReadSetting("output_type","compressed");
    options_source_map           = Script.ReadSetting("source_map","0");
    options_output_target        = Script.ReadSetting("output_target","current_folder");
    options_sass_auto_compile    = Script.ReadSetting("SASS Auto Compile","1");
    options_compass_auto_compile = Script.ReadSetting("Compass Auto Compile","1");
}

function CompileSass(Document)
{
    LoadSettings();

    var file = Document.FileName;
    var ext    = ExtractFileExt(file);

    // Detecting SASS file type:
    if(ext != ".scss")
        return false;

    // Check if is a Compass project
    var ContainerDir = ExtractFilePath(file);
    ContainerDir = Copy(ContainerDir, 0, Length(ContainerDir) - 1);
    ContainerDir = ExtractFilePath(ContainerDir);

    var OutputText;
    var BuildCommand;
    var IsCompass = FileExists( ContainerDir + "config.rb");

    if(IsCompass)
    {
        // Compass project mode compile

        if(options_compass_path == "")
        {
            Alert("Missing Compass path in plugin's settings. Go to Plugins > Save SASS > Compass settings... and set it.");
            return;
        }

        if(((options_compass_auto_compile == "0") && (!Manual)) || (ManualType == "SASS"))
        {
            return;
        }

        BuildCommand = options_compass_path + " compile '"+ContainerDir+"'";
        Script.Message("Compass project mode: "+BuildCommand);
    }
    else
    {
        if(options_sass_path == "")
        {
            Alert("Missing SASS path in plugin's settings. Go to Plugins > Save SASS > Sass settings... and set it.");
            return;
        }

        // Single SASS file compile
        if(((options_sass_auto_compile == "0") && (!Manual)) || (ManualType == "Compass"))
        {
            return;
        }

        var filename = ExtractFileName(file);
        filename = Copy(filename,0,Length(filename) - 5 );

        BuildCommand = options_sass_path + " '" + file + "' '";

        if(options_output_target=="current_folder")
        {
            BuildCommand += ExtractFilePath(file)+filename;
        }
        else if(options_output_target=="parent_folder")
        {
            ContainerDir = ExtractFilePath(file);
            ContainerDir = Copy(ContainerDir, 0, Length(ContainerDir) - 1);
            ContainerDir = ExtractFilePath(ContainerDir);
            BuildCommand += ContainerDir+filename;
        }
        else if(options_output_target=="css")
        {
            ContainerDir = ExtractFilePath(file);
            ContainerDir = Copy(ContainerDir, 0, Length(ContainerDir) - 1);
            ContainerDir = ExtractFilePath(ContainerDir);
            ExecuteCommand("php "+Script.Path+"\\script\\mkdir '"+ContainerDir+"css\\"+"'",Output);
            if(Output != "")
            {
                System.Message(Output);
            }
            BuildCommand += ContainerDir+"css\\"+filename;
        }
        else
        {
            ContainerDir = ExtractFilePath(file);
            ContainerDir = Copy(ContainerDir, 0, Length(ContainerDir) - 1);
            ContainerDir = ExtractFilePath(ContainerDir);
            ExecuteCommand("php "+Script.Path+"\\script\\mkdir '"+ContainerDir+"stylesheets\\"+"'",Output);
            if(Output != "")
            {
                System.Message(Output);
            }
            BuildCommand += ContainerDir+"stylesheets\\"+filename;
        }

        BuildCommand += ".css'";

        BuildCommand += " --style "+    options_output_type;

        if(options_source_map == "0")
        {
            BuildCommand += " --sourcemap=none ";
        }


        Script.Message("Single SASS (.scss) file mode:"+BuildCommand);
    }

    // Build:
    ExecuteCommand(BuildCommand, OutputText);

    if(IsCompass)
    {
        Script.Status = "Build complete. See Messages panel for result";
        Script.Message(OutputText);
    }
    else
    {
        if(OutputText == "")
        {
            Script.Status = "Build complete";
        }
        else
        {
            Script.Status = "Build error";
            Script.Message(OutputText);
        }
    }
}

function SassOptions()
{
    LoadSettings();

    var form = new TForm(WeBuilder);

    form.Width = 400;
    form.Height = 250;
    form.Position = poScreenCenter;
    form.BorderStyle = bsSingle;
    form.BorderIcons = biSystemMenu;
    form.Caption = "SASS compiler options";

    // SASS compile path
    var label_sass_path = new TLabel(form);
    label_sass_path.Parent = form;
    label_sass_path.Caption = "SASS Compiler path (with quotes):";
    label_sass_path.SetBounds(10, 8, 374, 15);

    var input_sass_path = new TEdit(form);
    input_sass_path.Parent = form;
    input_sass_path.Text = options_sass_path;
    input_sass_path.SetBounds(10, 24, 374, 21);

    // Output type
    var label_output_type = new TLabel(form);
    label_output_type.Parent = form;
    label_output_type.Caption = "Output type:";
    label_output_type.SetBounds(10, 60, 374, 15);

    var combo_output_type = new TComboBox(form);
    combo_output_type.Parent = form;
    combo_output_type.Style = csDropDownList;
    combo_output_type.setBounds(10, 75, 374, 15);
    combo_output_type.Items.Add("Expanded");
    combo_output_type.Items.Add("Nested");
    combo_output_type.Items.Add("Compact");
    combo_output_type.Items.Add("Compressed");

    if(options_output_type=="expanded")
    {
        combo_output_type.ItemIndex = 0;
    }
    else if(options_output_type=="nested")
    {
        combo_output_type.ItemIndex = 1;
    }
    else if(options_output_type=="compact")
    {
        combo_output_type.ItemIndex = 2;
    }
    else
    {
        combo_output_type.ItemIndex = 3;
    }

    // Output target
    var label_output_target = new TLabel(form);
    label_output_target.Parent = form;
    label_output_target.Caption = "Output destination target:";
    label_output_target.SetBounds(10, 110, 374, 15);

    var combo_output_target = new TComboBox(form);
    combo_output_target.Parent = form;
    combo_output_target.Style = csDropDownList;
    combo_output_target.setBounds(10, 125, 374, 15);
    combo_output_target.Items.Add("Current folder");
    combo_output_target.Items.Add("Parent folder");
    combo_output_target.Items.Add("../css");
    combo_output_target.Items.Add("../stylesheets (Compass default)");

    if(options_output_target=="current_folder")
    {
        combo_output_target.ItemIndex = 0;
    }
    else if(options_output_target=="parent_folder")
    {
        combo_output_target.ItemIndex = 1;
    }
    else if(options_output_target=="css")
    {
        combo_output_target.ItemIndex = 2;
    }
    else
    {
        combo_output_target.ItemIndex = 3;
    }

    // Source map checkbox
    var check_source_map = new TCheckBox(form);
    check_source_map.Parent = form;
    check_source_map.Checked = (options_source_map=="1");
    check_source_map.setBounds(10, 160, 15, 15);

    var label_source_map = new TLabel(form);
    label_source_map.Parent = form;
    label_source_map.Caption = "Source map";
    label_source_map.setBounds(28, 160, 326, 15);

    // Save button
    var button_ok = new TButton(form);
    button_ok.Parent = form;
    button_ok.SetBounds(8, 185, 75, 25);
    button_ok.Caption = "Save";
    button_ok.Default = True;
    button_ok.ModalResult = mrOK;

    // Cancel button
    var button_cancel = new TButton(form);
    button_cancel.Parent = form;
    button_cancel.SetBounds(95, 185, 75, 25);
    button_cancel.Caption = "Cancel";
    button_cancel.Cancel = True;
    button_cancel.ModalResult = mrCancel;

    var r = form.ShowModal;

    if(r==mrOK)
    {
        // Save settings:

        options_sass_path = input_sass_path.Text;

        if(combo_output_type.ItemIndex==0)
        {
            options_output_type = "expanded";
        }
        else if(combo_output_type.ItemIndex==1)
        {
            options_output_type = "nested";
        }
        else if(combo_output_type.ItemIndex==2)
        {
            options_output_type = "compact";
        }
        else
        {
            options_output_type = "compressed";
        }

        if(combo_output_target.ItemIndex==0)
        {
            options_output_target = "current_folder";
        }
        else if(combo_output_target.ItemIndex==1)
        {
            options_output_target = "parent_folder";
        }
        else if(combo_output_target.ItemIndex==2)
        {
            options_output_target = "css";
        }
        else
        {
            options_output_target = "stylesheets";
        }

        if(check_source_map.Checked)
        {
            options_source_map = "1";
        }
        else
        {
            options_source_map = "0";
        }

        Script.WriteSetting("sass_path",options_sass_path);
        Script.WriteSetting("output_type",options_output_type);
        Script.WriteSetting("source_map",options_source_map);
        Script.WriteSetting("output_target",options_output_target);
    }
    delete f;
}

function CompassOptions()
{
    LoadSettings();

    var form = new TForm(WeBuilder);

    form.Width = 400;
    form.Height = 130;
    form.Position = poScreenCenter;
    form.BorderStyle = bsSingle;
    form.BorderIcons = biSystemMenu;
    form.Caption = "Compass options";

    // Compass    path
    var label_compass_path = new TLabel(form);
    label_compass_path.Parent = form;
    label_compass_path.Caption = "Compass path (with quotes):";
    label_compass_path.SetBounds(10, 8, 374, 15);

    var input_compass_path = new TEdit(form);
    input_compass_path.Parent = form;
    input_compass_path.Text = options_compass_path;
    input_compass_path.SetBounds(10, 24, 374, 21);

    var label_compasss_note = new TLabel(form);
    label_compasss_note.Parent = form;
    label_compasss_note.Caption = "For Compass existing project settings you must edit their config.rb file";
    label_compasss_note.SetBounds(10, 48, 376, 15);

    // Save button
    var button_ok = new TButton(form);
    button_ok.Parent = form;
    button_ok.SetBounds(8, 70, 75, 25);
    button_ok.Caption = "Save";
    button_ok.Default = true;
    button_ok.ModalResult = mrOK;

    // Cancel button
    var button_cancel = new TButton(form);
    button_cancel.Parent = form;
    button_cancel.SetBounds(95, 70, 75, 25);
    button_cancel.Caption = "Cancel";
    button_cancel.Cancel = True;
    button_cancel.ModalResult = mrCancel;

    var r = form.ShowModal;

    if(r==mrOK)
    {
        // Save settings:
        options_compass_path = input_compass_path.Text;
        Script.WriteSetting("compass_path",options_compass_path);
    }
    delete f;
}
function CreateCompassProject()
{
    LoadSettings();

    if(options_compass_path == "")
    {
        Alert("Missing Compass path in plugin's settings. Go to Plugins > Save SASS > Compass settings... and set it.");
        return;
    }

    cform = new TForm(WeBuilder);

    cform.Width = 400;
    cform.Height = 170;

    //cform.Position = poScreenCenter;
    cform.Position = poScreenCenter;
    cform.BorderStyle = bsSingle;
    cform.BorderIcons = biSystemMenu;
    cform.Caption = "Compass Project Wizard";

    var label_compass_path = new TLabel(cform);
    label_compass_path.Parent = cform;
    label_compass_path.Caption = "Installation target (with quotes):";
    label_compass_path.SetBounds(10, 8, 374, 15);

    input_compass_inst_path = new TEdit(cform);
    input_compass_inst_path.Parent = cform;
    input_compass_inst_path.SetBounds(10, 25, 295, 21);

    var button_open = new TButton(cform);
    button_open.Parent = cform;
    button_open.SetBounds(310, 24, 75, 24);
    button_open.Caption = "Browse";
    button_open.Default = True;
    button_open.onClick = "SelectCompassFolderDialog";

    var check_use_custom_settings = new TCheckBox(cform);
    check_use_custom_settings.Parent = cform;
    check_use_custom_settings.Checked = (options_source_map=="1");
    check_use_custom_settings.setBounds(10, 55, 15, 15);

    var label_use_custom_settings = new TLabel(cform);
    label_use_custom_settings.Parent = cform;
    label_use_custom_settings.Caption = "Use custom settings (in plugin's Options)";
    label_use_custom_settings.setBounds(28, 55, 326, 15);

    var check_use_bootstrap = new TCheckBox(cform);
    check_use_bootstrap.Parent = cform;
    check_use_bootstrap.Checked = (options_source_map=="1");
    check_use_bootstrap.setBounds(10, 78, 15, 15);
    check_use_bootstrap.OnClick = "TogglePreview";

    var label_use_bootstrap = new TLabel(cform);
    label_use_bootstrap.Parent = cform;
    label_use_bootstrap.Caption = "Use Bootstrap (requires Compass's bootstrap-sass gem)";
    label_use_bootstrap.setBounds(28, 78, 326, 15);

    combo_bootstrap_theme = new TComboBox(cform);
    combo_bootstrap_theme.Parent = cform;
    combo_bootstrap_theme.Style = csDropDownList;
    combo_bootstrap_theme.setBounds(10, 100, 375, 10);
    combo_bootstrap_theme.Items.Add("Bootstrap default theme");
    combo_bootstrap_theme.Items.Add("Cerulean");
    combo_bootstrap_theme.Items.Add("Cosmo");
    combo_bootstrap_theme.Items.Add("Cyborg");
    combo_bootstrap_theme.Items.Add("Darkly");
    combo_bootstrap_theme.Items.Add("Flatly");
    combo_bootstrap_theme.Items.Add("Journal");
    combo_bootstrap_theme.Items.Add("Lumen");
    combo_bootstrap_theme.Items.Add("Paper");
    combo_bootstrap_theme.Items.Add("Readable");
    combo_bootstrap_theme.Items.Add("Sandstone");
    combo_bootstrap_theme.Items.Add("Simplex");
    combo_bootstrap_theme.Items.Add("Slate");
    combo_bootstrap_theme.Items.Add("Spacelab");
    combo_bootstrap_theme.Items.Add("Superhero");
    combo_bootstrap_theme.Items.Add("United");
    combo_bootstrap_theme.Items.Add("Yeti");
    combo_bootstrap_theme.ItemIndex = 0;
    combo_bootstrap_theme.OnChange = "ChangeBootstrapPreviewImage";
    combo_bootstrap_theme.Visible = false;

    image_bootstrap_theme = new TImage(cform);
    image = new TPicture();
    image.LoadFromFile(Script.Path + "\\bootstrap\\default\\thumbnail.png");

    image_bootstrap_theme.Parent = cform;
    image_bootstrap_theme.Picture = image;
    image_bootstrap_theme.Proportional = true;
    //image_bootstrap_theme.setBounds(10, 130, 375, 280);
    image_bootstrap_theme.setBounds(1, 1, 1, 1);

    // Save button
    cbutton_ok = new TButton(cform);
    cbutton_ok.Parent = cform;
    cbutton_ok.SetBounds(115, 110, 75, 25);
    cbutton_ok.Caption = "Create";
    cbutton_ok.Default = True;
    cbutton_ok.ModalResult = mrOK;

    // Cancel button
    cbutton_cancel = new TButton(cform);
    cbutton_cancel.Parent = cform;
    cbutton_cancel.SetBounds(195, 110, 75, 25);
    cbutton_cancel.Caption = "Cancel";
    cbutton_cancel.Cancel = True;
    cbutton_cancel.ModalResult = mrCancel;

    var r = cform.ShowModal;

    if(r==mrOK)
    {
        if(input_compass_inst_path.Text == "")
        {
            Alert("You must specify an Installation path!");
        }
        else
        {
            var theme = combo_bootstrap_theme.ItemIndex;
            var theme_name;
            var CompassThemePath  = Script.Path + "\\bootstrap\\";
            var InstallPath       = input_compass_inst_path.Text;
            var InstallCommand    = options_compass_path+" create \""+InstallPath+"\"";
            var UseBootstrap      = check_use_bootstrap.Checked;
            var UseCustomSettings = check_use_custom_settings.Checked;
            var Output;
            var OutputStyle  = Script.ReadSetting("Compass Output Style","expanded");
            var LineComments = (Script.ReadSetting("Compass Line Comments","0") == "1");
            var SassDir = Script.ReadSetting("Compass SASS folder","sass");

            if((OutputStyle != "expanded") && (OutputStyle != "nested") && (OutputStyle != "compact") && (OutputStyle != "compressed") )
            {
                Script.Message("WARNING: Unknow output style '"+OutputStyle+"'. Using 'expanded' instead");
                OutputStyle = "expanded";
            }

            if(UseBootstrap)
            {
                InstallCommand += " -r bootstrap-sass --using bootstrap";
                if(theme == 0)
                {
                    CompassThemePath  += "default" ;
                }
                else if(theme == 1)
                {
                    CompassThemePath  += "cerulean" ;
                    theme_name  = "cerulean" ;
                }
                else if(theme == 2)
                {
                    CompassThemePath  += "cosmo" ;
                    theme_name  = "cosmo" ;
                }
                else if(theme == 3)
                {
                    CompassThemePath  += "cyborg" ;
                    theme_name  = "cyborg" ;
                }
                else if(theme == 4)
                {
                    CompassThemePath  += "darkly" ;
                    theme_name  = "darkly" ;
                }
                else if(theme == 5)
                {
                    CompassThemePath  += "flatly" ;
                    theme_name  = "flatly" ;
                }
                else if(theme == 6)
                {
                    CompassThemePath  += "journal" ;
                    theme_name  = "journal" ;
                }
                else if(theme == 7)
                {
                    CompassThemePath  += "lumen" ;
                    theme_name  = "lumen" ;
                }
                else if(theme == 8)
                {
                    CompassThemePath  += "paper" ;
                    theme_name  = "paper" ;
                }
                else if(theme == 9)
                {
                    CompassThemePath  += "readable" ;
                    theme_name  = "readable" ;
                }
                else if(theme == 10)
                {
                    CompassThemePath  += "sandstone" ;
                    theme_name  = "sandstone" ;
                }
                else if(theme == 11)
                {
                    CompassThemePath  += "simplex" ;
                    theme_name  = "simplex" ;
                }
                else if(theme == 12)
                {
                    CompassThemePath  += "slate" ;
                    theme_name  = "slate" ;
                }
                else if(theme == 13)
                {
                    CompassThemePath  += "spacelab" ;
                    theme_name  = "spacelab" ;
                }
                else if(theme == 14)
                {
                    CompassThemePath  += "superhero" ;
                    theme_name  = "superhero" ;
                }
                else if(theme == 15)
                {
                    CompassThemePath  += "united" ;
                    theme_name  = "united" ;
                }
                else
                {
                    CompassThemePath  += "yeti" ;
                    theme_name  = "yeti" ;
                }
            }

            if(UseCustomSettings)
            {
                InstallCommand += " --css-dir="  +  Script.ReadSetting("Compass CSS folder","stylesheets");
                InstallCommand += " --sass-dir=" +  SassDir;
                InstallCommand += " --javascripts-dir="  +  Script.ReadSetting("Compass JS folder","javascripts");
                InstallCommand += " --images-dir="       +  Script.ReadSetting("Compass Image folder","images");
                InstallCommand += " --output-style="+OutputStyle;
            }

            if((Script.ReadSetting("Compass Line Comments","0")) == "0")
            {
                InstallCommand += " --no-line-comments";
            }

            if(options_compass_path == "")
            {
                Alert("Missing Compass path in plugin's settings. Go to Plugins > Save SASS > Compass settings... and set it.");
                return;
            }

            ExecuteCommand(InstallCommand, Output);
            Script.Message(Output);


            if((UseBootstrap) && (theme != 0))
            {
                // Copy styles.scss template:
                var CopyCommand =  "php "+Script.Path+"script\\copy ";
                CopyCommand += "\""+Script.Path+"bootstrap\\styles.scss\" ";
                CopyCommand += "\""+InstallPath;

                if(UseCustomSettings)
                {
                   CopyCommand += "\\"+SassDir+"\\";
                }
                else
                {

                    CopyCommand += "\\sass\\";
                }

                CopyCommand += "styles.scss\"";
                ExecuteCommand(CopyCommand,Output);
                System.Message(Output);

                // Make _bootswatch.scss empty file
                var CreateCommand =  "php "+Script.Path+"script\\mkfile ";
                CreateCommand += "\""+InstallPath;

                if(UseCustomSettings)
                {
                    CreateCommand += "\\"+SassDir+"\\";
                }
                else
                {
                    CreateCommand += "\\sass\\";
                }

                CreateCommand += "_bootswatch.scss\"";
                ExecuteCommand(CreateCommand,Output);
                System.Message(Output);

                // Copy current _bootswatch.scss file's theme
                CopyCommand =  "php "+Script.Path+"script\\copy ";
                CopyCommand += "\""+Script.Path+"bootstrap\\"+theme_name+"\\_bootswatch.scss\" ";
                CopyCommand += "\""+InstallPath;

                if(UseCustomSettings)
                {
                   CopyCommand += "\\"+SassDir+"\\";
                }
                else
                {

                    CopyCommand += "\\sass\\";
                }

                CopyCommand += "_bootswatch.scss\"";
                ExecuteCommand(CopyCommand,Output);
                System.Message(Output);

                // Copy current _bootstrap-variables.scss file's theme
                CopyCommand =  "php "+Script.Path+"script\\copy ";
                CopyCommand += "\""+Script.Path+"bootstrap\\"+theme_name+"\\_bootstrap-variables.scss\" ";
                CopyCommand += "\""+InstallPath;
                if(UseCustomSettings)
                {
                   CopyCommand += "\\"+SassDir+"\\";
                }
                else
                {

                    CopyCommand += "\\sass\\";
                }

                CopyCommand += "_bootstrap-variables.scss\"";
                ExecuteCommand(CopyCommand,Output);
                System.Message(Output);
            }

            Script.Message("Project created succefully");
            var BuildCommand = options_compass_path + " compile '"+InstallPath+"'";
            Script.Message("Building compass project: "+BuildCommand);
            ExecuteCommand(BuildCommand,Output);
            Script.Message("Build complete");
            System.Message(Output);
        }
    }
    delete f;
}

function SelectCompassFolderDialog()
{
    var folder = "C:/";
    if(BrowseForFolder(folder, "Select folder", true)) {
        folder = "\""+folder+"\"";
        input_compass_inst_path.Text = folder;
    }
}

function TogglePreview(Sender)
{

    if(Sender.Checked)
    {
        cform.Height = 420;
        combo_bootstrap_theme.Visible = true;
        image_bootstrap_theme.setBounds(10, 130, 375, 280);
        cbutton_ok.SetBounds(115, 360, 75, 25);
        cbutton_cancel.SetBounds(195, 360, 75, 25)
    }
    else
    {
        cform.Height = 170;
        combo_bootstrap_theme.Visible = false;
        image_bootstrap_theme.setBounds(1, 1, 1, 1);
        cbutton_ok.SetBounds(115, 110, 75, 25);
        cbutton_cancel.SetBounds(195, 110, 75, 25)
    }
    cform.Position = poScreenCenter;
}

function ChangeBootstrapPreviewImage(Sender)
{
    var path = Script.Path + "\\bootstrap\\";
    var current = Sender.ItemIndex;

    if(current == 0)
    {
        path  += "default" ;
    }
    else if(current == 1)
    {
        path  += "cerulean" ;
    }
    else if(current == 2)
    {
        path  += "cosmo" ;
    }
    else if(current == 3)
    {
        path  += "cyborg" ;
    }
    else if(current == 4)
    {
        path  += "darkly" ;
    }
    else if(current == 5)
    {
        path  += "flatly" ;
    }
    else if(current == 6)
    {
        path  += "journal" ;
    }
    else if(current == 7)
    {
        path  += "lumen" ;
    }
    else if(current == 8)
    {
        path  += "paper" ;
    }
    else if(current == 9)
    {
        path  += "readable" ;
    }
    else if(current == 10)
    {
        path  += "sandstone" ;
    }
    else if(current == 11)
    {
        path  += "simplex" ;
    }
    else if(current == 12)
    {
        path  += "slate" ;
    }
    else if(current == 13)
    {
        path  += "spacelab" ;
    }
    else if(current == 14)
    {
        path  += "superhero" ;
    }
    else if(current == 15)
    {
        path  += "united" ;
    }
    else
    {
        path  += "yeti" ;
    }

    path += "\\thumbnail.png";
    image.LoadFromFile( path );
    image_bootstrap_theme.Picture = image;

}
function ManualCompileSass()
{
    Manual = true;
    ManualType = "SASS";
    CompileSass(Document);
}
function ManualCompileCompass()
{
    Manual = true;
    ManualType = "Compass"
    CompileSass(Document);
}

Script.ConnectSignal("document_after_save", &CompileSass);
Script.RegisterAction("Compass", "Create project", "", &CreateCompassProject);
Script.RegisterAction("Compass", "Build current project", "", &ManualCompileCompass);
Script.RegisterAction("Compass", "Settings...", "", &CompassOptions);
Script.RegisterAction("SASS", "Build current file", "", &ManualCompileSass);
Script.RegisterAction("SASS", "Settings...", "", &SassOptions);
